.. Salmon documentation master file, created by
   sphinx-quickstart on Mon Aug 24 22:13:47 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Salmon - A Python Mail Server
=============================

.. include:: ../README.rst
  :start-after: inclusion-marker-do-not-remove-start
  :end-before: inclusion-marker-do-not-remove-end


Contents:

.. toctree::
    :maxdepth: 2

    getting_started
    routing
    relaying
    mail_objects
    Salmon API guide <salmon>

About Salmon
============

.. toctree::
    :maxdepth: 2

    changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

